@@ -99,7 +99,7 @@ CLI_COMMANDS_HELP = {
                 """,
     },
     'network': {
-        'layout_subnet_plan': """Layout subnet plan.\n
+        'subnet': """Get subnet plan layout of the applcation.\n
                 """,
 
     }
@@ -151,7 +151,7 @@ CLI_COMMANDS_SHORT_HELP = {
         'init': "Initialize DSO configuration for the working directory.",
     },
     'network': {
-        'layout_subnet_plan': "Layout subnet plan group.",
+        'subnet': "Get subnet plan layout of the application.",
 
     }
 
@@ -249,7 +249,7 @@ CLI_MESSAGES = {
     # 'InvalidRenderPath': "'{0}' is not a valid render path.",
     'InvalidRenderPathExistingDir': "'{0}' is not a valid render path because it is an existing directory.",
     'InvalidFilter': "Invalid regex pattern for filter: {0}",
-    'NoChanegeDetectedAfterEditing': "No change detected after editing.",
+    'NoChanegeDetectedAfterEditing': "Edit canceled, no change detected after editing.",
     'ParameterNotFound': "Parameter '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
     'SecretNotFound': "Secret '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
     'TemplateNotFound': "Template '{0}' not found in the given context: namespace={1}, project={2}, application={3}, stage={4}, scope={5}",
