@@ -40,7 +40,7 @@ _default_config = {
     'version': 1,
     'namespace': 'default',
     'project': 'default',
-    'application': 'application',
+    'application': 'default',
     'network':{
         'subnetPlanGroup': '',
         'subnetPlan': '',
@@ -100,7 +100,7 @@ class ConfigService:
     global_config_rendered = {}
     global_config_file_path = ''
     global_config_dir_path = ''
-    inherited_config_rendered = {}
+    inherited_config = {}  ### consolidated across all inherited configs, always rendered
     inherited_config_files = []
     overriden_config = {}
     merged_config = {}
@@ -109,15 +109,14 @@ class ConfigService:
 
     def load(self, working_dir, config_overrides_string='', stage=None, scope=None):
         self.working_dir = working_dir
-        ### call first to set meta data for rendering
-        self.update_merged_config()
+        ### start off with given stage, scope, and overriden config to set meta_data for subsequent rendering
+        self.context = Context('default', 'default', 'default', stage, scope)
+        self.apply_config_overrides(config_overrides_string)
+
+        ### now start the normal loading process
         self.load_global_config()
         self.load_inherited_config()
         self.load_local_config()
-        self.apply_config_overrides(self.config_string_to_dict(config_overrides_string))
-        self.context = Context(self.merged_config['namespace'], self.merged_config['project'], self.merged_config['application'], stage, scope)
-        ### call to add context to config
-        self.update_merged_config()
         self.check_version()
 
 
@@ -140,9 +139,12 @@ class ConfigService:
         try:
             self.global_config = load_file(self.global_config_file_path)
             if render:
+                ### call update using not rendered config for in-place rendering of the global config iteself
+                self.update_merged_config(use_global_rendered=False)
+                ### now do the rendering            
                 self.global_config_rendered = load_file(self.global_config_file_path, pre_render_values=self.meta_vars)
             else:
-                self.global_config_rendered = load_file(self.global_config_file_path)
+                self.global_config_rendered = self.global_config.copy()
 
         except:
             raise DSOException(MESSAGES['InvalidDSOConfigurationFile'].format(self.global_config_file_path))
@@ -163,10 +165,13 @@ class ConfigService:
 
         try:
             self.local_config = load_file(self.local_config_file_path)
-            if render: 
+            if render:
+                ### call update using not rendered config for in-place rendering of the local config iteself
+                self.update_merged_config(use_local_rendered=False)
+                ### now do the rendering            
                 self.local_config_rendered = load_file(self.local_config_file_path, pre_render_values=self.meta_vars)
             else:
-                self.local_config_rendered = load_file(self.local_config_file_path)
+                self.local_config_rendered = self.local_config.copy()
 
         except:
             raise DSOException(MESSAGES['InvalidDSOConfigurationFile'].format(self.local_config_file_path))
@@ -175,7 +180,7 @@ class ConfigService:
 
     def load_inherited_config(self, render=True):
 
-        self.inherited_config_rendered = {}
+        self.inherited_config = {}
 
         for dir in Path(self.working_dir).resolve().parents:
             configFilePath = os.path.join(dir, self.config_dir, self.config_file)
@@ -187,14 +192,21 @@ class ConfigService:
 
         for configFilePath in reversed(self.inherited_config_files):
             try:
+                config = load_file(configFilePath)
                 if render:
+                    ### use raw config for inplace rendering, otherwise have to keep a copy of raw/rendetred for each inherited config file
+                    merge_dicts(config, self.inherited_config)
+                    ### update meta_vars
+                    self.update_merged_config()
+                    ### now do the rendering
                     config = load_file(configFilePath, pre_render_values=self.meta_vars)
-                else:
-                    config = load_file(configFilePath)
             except:
                 raise DSOException(MESSAGES['InvalidDSOConfigurationFile'].format(configFilePath))
             
-            self.inherited_config_rendered = merge_dicts(config, self.inherited_config_rendered)
+            ### merge rendered inherited config
+            merge_dicts(config, self.inherited_config)
+            ### call update for next meta var rendering
+            self.update_merged_config()
 
         self.update_merged_config()
 
@@ -223,6 +235,8 @@ class ConfigService:
     def apply_config_overrides(self, config_overrides):
         self.overriden_config = {}
         if config_overrides:
+            if isinstance(config_overrides, str):
+                config_overrides = self.config_string_to_dict(config_overrides)
             configs = flatten_dict(config_overrides)
             for key, value in configs.items():
                 existing = get_dict_item(self.merged_config, key.split('.'))
@@ -235,11 +249,11 @@ class ConfigService:
         self.update_merged_config()
 
 
-    def update_merged_config(self):
+    def update_merged_config(self, use_global_rendered=True, use_local_rendered=True):
         self.merged_config = get_default_config()
-        merge_dicts(self.global_config_rendered, self.merged_config)
-        merge_dicts(self.inherited_config_rendered, self.merged_config)
-        merge_dicts(self.local_config_rendered, self.merged_config)
+        merge_dicts(self.global_config_rendered if use_global_rendered else self.global_config, self.merged_config)
+        merge_dicts(self.inherited_config, self.merged_config)
+        merge_dicts(self.local_config_rendered if use_local_rendered else self.local_config, self.merged_config)
         providers = ['parameter', 'secret', 'template']
         
         ### save provider ids before overriding
@@ -249,8 +263,6 @@ class ConfigService:
             if providerId:
                 saved_provider_ids[provider] = providerId
         
-        merge_dicts(self.overriden_config, self.merged_config)
-        
         ### add missing default specs for each provider
         for provider in providers:
             providerId = self.get_provider_id(provider)
@@ -263,6 +275,9 @@ class ConfigService:
                 else:
                     self.merged_config[provider]['provider']['spec'] = self.get_provider_default_spec(provider, providerId)
 
+        merge_dicts(self.overriden_config, self.merged_config)
+        self.context = Context(self.merged_config['namespace'], self.merged_config['project'], self.merged_config['application'], self.stage, self.scope)
+
         self.merged_config['context'] = {
             'namespace': self.namespace,
             'project': self.project,
@@ -274,6 +289,7 @@ class ConfigService:
         self.merged_config['stage'] = self.get_stage(ContextSource.Target, short=True)
         self.merged_config['scope'] = str(self.scope)
 
+
     def check_version(self):
         if not int(self.merged_config['version']) == int(_default_config['version']):
             if int(self.merged_config['version']) > int(_default_config['version']):
@@ -510,7 +526,8 @@ class ConfigService:
             Logger.info(f"Unsetting '{key}' from the global DSO configurations...")
             parent = get_dict_item(self.global_config, key.split('.')[:-1])
             if parent and key.split('.')[-1] in parent:
-                parent.pop(key.split('.')[-1])
+                del_dict_item(dic=self.global_config, keys=key.split('.'))
+                del_dict_empty_item(dic=self.global_config, keys=key.split('.')[:-1])
                 self.save_global_config()
                 self.load_global_config()
             else:
@@ -519,7 +536,8 @@ class ConfigService:
             Logger.info(f"Unsetting '{key}' from the local DSO configurations...")
             parent = get_dict_item(self.local_config, key.split('.')[:-1])
             if parent and key.split('.')[-1] in parent:
-                parent.pop(key.split('.')[-1])
+                del_dict_item(dic=self.local_config, keys=key.split('.'))
+                del_dict_empty_item(dic=self.local_config, keys=key.split('.')[:-1])
                 self.save_local_config()
                 self.load_local_config()
             else:
@@ -561,7 +579,7 @@ class ConfigService:
 
                     Logger.debug("Merging inherited configuration...")
                     self.load_inherited_config(render=False)
-                    merge_dicts(self.inherited_config_rendered, config)
+                    merge_dicts(self.inherited_config, config)
                 
                 ### do not show warning if directory is not initialized yet
                 Logger.debug("Merging existing configuration...")
@@ -571,7 +589,7 @@ class ConfigService:
             ### if config overrides, merge them to local
             if config_overrides_string:
                 Logger.debug("Merging configuration overrides...")
-                self.apply_config_overrides(self.config_string_to_dict(config_overrides_string))
+                self.apply_config_overrides(config_overrides_string)
                 merge_dicts(self.overriden_config, config)
 
             self.local_config = config
@@ -605,7 +623,7 @@ class ConfigService:
             ### if config overrides, merge them to local
             if config_overrides_string:
                 Logger.debug("Merging configuration overrides...")
-                self.apply_config_overrides(self.config_string_to_dict(config_overrides_string))
+                self.apply_config_overrides(config_overrides_string)
                 merge_dicts(self.overriden_config, config)
 
             self.global_config = config
