@@ -3,15 +3,6 @@ from .logger import Logger
 from .exceptions import DSOException
 
 
-def clean_directory(path):
-    for path in Path(path).glob("**/*"):
-        if path.is_file():
-            path.unlink()
-        elif path.is_dir():
-            rmtree(path)
-
-
-
 
 # def merge_dicts(source, destination):
 #     if not source: return destination
@@ -220,40 +211,26 @@ def set_dict_value(dic, keys, value, overwrite_parent=False, overwrite_children=
 
 
 
-def del_dict_item(dic, keys):
-    item = get_dict_item(dic, keys[:-1], create=False)
-    if not item or not keys[-1] in item:
+def del_dict_item(dic, keys, force=False):
+    parent_item = get_dict_item(dic, keys[:-1], create=False)
+    if not parent_item or not keys[-1] in parent_item:
         return False
 
-    if isinstance(item[keys[-1]], dict):
+    if isinstance(parent_item[keys[-1]], dict) and not force:
         raise DSOException("'{0}' is a non-empty namespace and cannot be deleted.".format('.'.join(keys)))
 
-    item.pop(keys[-1])
+    parent_item.pop(keys[-1])
     return True
 
 
 
 def del_dict_empty_item(dic, keys):
-    if not dic: return
     item = get_dict_item(dic, keys)
     if not item:
-        item = get_dict_item(dic, keys[:-1])
-        item.pop(keys[-1])
-        del_dict_empty_item(dic, keys[:-1])
+        del_dict_item(dic, keys, force=True)
+        if len(keys) > 1:
+            del_dict_empty_item(dic, keys[:-1])
 
-
-
-def is_binary_file(filename):
-    """ 
-    Return true if the given filename appears to be binary.
-    File is considered to be binary if it contains a NULL byte.
-    FIXME: This approach incorrectly reports UTF-16 as binary.
-    """
-    with open(filename, 'rb') as f:
-        for block in f:
-            if b'\0' in block:
-                return True
-    return False
 
 
 
