@@ -70,7 +70,7 @@ def get_user_data_dir(appname):
     else:
         raise NotImplementedError
     os.makedirs(result.joinpath(appname, 'logs'), exist_ok=True)
-    return result.joinpath(appname)
+    return result.joinpath(appname, 'logs')
 
 
 def get_log_file_name():
