@@ -67,7 +67,7 @@ class AwsSsmSecretProvider(SecretProvider):
                     'Namespace': config.namespace,
                     'Project': config.project,
                     'Application': config.application,
-                    'Stage': config.short_stage,
+                    'Stage': config.stage,
                 },
                 'Path': path,
             }
