@@ -44,41 +44,41 @@ class ProviderManager():
     #     # importdir.do(os.path.dirname(__file__)+'/secret_providers', globals())
     #     # importdir.do(os.path.dirname(__file__)+'/template_providers', globals())
 
-    def load_provider(self, provider_id):
-        Logger.debug(f"Loading provider '{provider_id}'...")
-        providerPackagePath = os.path.join(Configs.install_path, 'provider', provider_id)
+    def load_provider(self, provider_slug):
+        Logger.debug(f"Loading provider '{provider_slug}'...")
+        providerPackagePath = os.path.join(Configs.install_path, 'provider', provider_slug)
         if not os.path.exists(providerPackagePath):
-            raise DSOException(f"Providers '{provider_id}' not found.")
-        imp.load_package(provider_id, providerPackagePath).register()
+            raise DSOException(f"Provider '{provider_slug}' not found.")
+        imp.load_package(provider_slug, providerPackagePath).register()
 
     def register(self, provider: ProviderBase):
         if not provider.id in self.__providers:
             self.__providers[provider.id] = provider
-            Logger.debug(f"Providers registered: id ={provider.id}")
+            Logger.debug(f"Provider registered: id ={provider.id}")
 
-    def get_provider(self, provider_id):
-        if not provider_id in self.__providers:
-            self.load_provider(provider_id)
+    def get_provider(self, provider_slug):
+        if not provider_slug in self.__providers:
+            self.load_provider(provider_slug)
 
         ### make sure provider has registered, and return it
-        if provider_id in self.__providers:
-            return self.__providers[provider_id] 
+        if provider_slug in self.__providers:
+            return self.__providers[provider_slug] 
         else:
-            raise DSOException(f"No provider has registered for '{provider_id}'.")
+            raise DSOException(f"No provider has registered for '{provider_slug}'.")
 
     def ParameterProvider(self):
         if not Configs.parameter_provider:
-            raise DSOException('Parameter provider has not been set.')
+            raise DSOException(MESSAGES['ProviderNotSet'].format('Parameter'))
         return self.get_provider('parameter/' + Configs.parameter_provider)
 
-    def TemplateProvider(self):
-        if not Configs.template_provider:
-            raise DSOException('Template provider has not been set.')
-        return self.get_provider('template/' + Configs.template_provider)
-
     def SecretProvider(self):
         if not Configs.secret_provider:
-            raise DSOException('Secret provider has not been set.')
+            raise DSOException(MESSAGES['ProviderNotSet'].format('Secret'))
         return self.get_provider('secret/' + Configs.secret_provider)
 
+    def TemplateProvider(self):
+        if not Configs.template_provider:
+            raise DSOException(MESSAGES['ProviderNotSet'].format('Template'))
+        return self.get_provider('template/' + Configs.template_provider)
+
 Providers = ProviderManager()
